# fondat

[![PyPI](https://img.shields.io/pypi/v/fondat)](https://pypi.org/project/fondat/)
[![Python](https://img.shields.io/pypi/pyversions/fondat)](https://python.org/)
[![GitHub](https://img.shields.io/badge/github-main-blue.svg)](https://github.com/fondat/fondat/)
[![Test](https://github.com/fondat/fondat/workflows/test/badge.svg)](https://github.com/fondat/fondat/actions?query=workflow/test)
[![License](https://img.shields.io/github/license/fondat/fondat.svg)](https://github.com/fondat/fondat/blob/main/LICENSE)

A foundation for resource-oriented backend applications.

## Introduction

Fondat is a foundation for resource-oriented backend applications in Python.

## Install

```
pip install fondat
```

## Develop

```
poetry install
poetry run pre-commit install
```

## Test

```
poetry run pytest
```